summaryrefslogtreecommitdiffstats
path: root/chromium/content/renderer/media/audio_device_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/renderer/media/audio_device_factory.h')
-rw-r--r--chromium/content/renderer/media/audio_device_factory.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chromium/content/renderer/media/audio_device_factory.h b/chromium/content/renderer/media/audio_device_factory.h
index 46bf5f96099..3865753d8d0 100644
--- a/chromium/content/renderer/media/audio_device_factory.h
+++ b/chromium/content/renderer/media/audio_device_factory.h
@@ -7,6 +7,7 @@
#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
+#include "content/common/content_export.h"
namespace media {
class AudioInputDevice;
@@ -18,13 +19,13 @@ namespace content {
// A factory for creating AudioOutputDevices and AudioInputDevices. There is a
// global factory function that can be installed for the purposes of testing to
// provide specialized implementations.
-class AudioDeviceFactory {
+class CONTENT_EXPORT AudioDeviceFactory {
public:
// Creates an AudioOutputDevice using the currently registered factory.
// |render_view_id| refers to the render view containing the entity producing
// the audio.
static scoped_refptr<media::AudioOutputDevice> NewOutputDevice(
- int render_view_id);
+ int render_view_id, int render_frame_id);
// Creates an AudioInputDevice using the currently registered factory.
// |render_view_id| refers to the render view containing the entity consuming
@@ -18,13 +19,13 @@ namespace content {
public:
// Creates an AudioOutputDevice using the currently registered factory.
- // |render_view_id| refers to the render view containing the entity producing
- // the audio.
+ // |render_view_id| and |render_frame_id| refer to the render view and render
+ // frame containing the entity producing the audio.
static scoped_refptr<media::AudioOutputDevice> NewOutputDevice(